@@ -66,13 +66,13 @@ class SimplePather(Pather):
             if os.path.exists(apath):
                 return apath
         if len(self._exts) == 1:
-            logging.info("SimplePather._find_path: no file. just one ext. we assume name + '.' + ext")
+            logging.info(f"SimplePather._find_path: no file. just one ext. we assume name + '.' + ext")
             return path + "." + self._exts[0]
         elif len(self._exts) > 1:
-            logging.warning("SimplePather._find_path: on file. there are {len(self._exts)} exts, so we guess the first one.")
+            logging.warning(f"SimplePather._find_path: on file. there are {len(self._exts)} exts, so we guess the first one.")
             return path + "." + self._exts[0]
         else:
-            logging.warning("SimplePather._find_path: no exts! this is bad.")
+            logging.warning("SimplePather._find_path: no exts! you should fix this.")
         return None
 
     def get_filename(self, path:str) -> Optional[str]:
